import Flutter
import UIKit

public class SwiftStripePlugin: NSObject, FlutterPlugin {
    public static func register(with registrar: FlutterPluginRegistrar) {
        let channel = FlutterMethodChannel(name: "stripe_plugin", binaryMessenger: registrar.messenger())
        let instance = SwiftStripePlugin()
        registrar.addMethodCallDelegate(instance, channel: channel)
    }
    
    // public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
    //   result("iOS " + UIDevice.current.systemVersion)
    // }
    
    public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
                
        let stripeKey = string(for: "stripeKey", in: call)
        let backendBaseURL = string(for: "backendBaseURL", in: call)
        let appleMerchantID = string(for: "appleMerchantID", in: call)
        let ephemeralKey = anyHashable(for: "ephemeralKey", in: call)
        let orderId = string(for: "orderId", in: call)        
        let authToken = string(for: "authToken", in: call)        
        
        var helpCenter = ViewController(with: stripeKey, backendBaseURL: backendBaseURL, appleMerchantID: appleMerchantID, ephemeralKey: ephemeralKey, orderId: orderId,authToken : authToken)
        helpCenter.onClose = {
            
        }
        
        helpCenter.onSuccess = { (stripeId) in
            result(stripeId)
        }
       
        helpCenter.onError = { (error) in
            result(FlutterError.init(code: "2", message: error, details: nil))
        }
        
        helpCenter.onCancel = {
            result(FlutterError.init(code: "3", message: "cancalled", details: nil))
        }
        
        let rootViewController:UIViewController! = UIApplication.shared.keyWindow?.rootViewController
        
        if (rootViewController is UINavigationController) {
            (rootViewController as! UINavigationController).pushViewController(helpCenter,animated:true)
        } else {
            let navigationController:UINavigationController! = UINavigationController(rootViewController:helpCenter)
            rootViewController.present(navigationController, animated:true, completion:nil)
        }        
    }
    
    private func string(for key: String, in call: FlutterMethodCall) -> String {
           return (call.arguments as? [String: Any])?[key] as! String
       }
       
       
       private func bool(for key: String, in call: FlutterMethodCall) -> Bool {
           return (call.arguments as? [String: Any])?[key] as! Bool
       }
    
    private func anyHashable(for key: String, in call: FlutterMethodCall) ->  [AnyHashable : Any] {
              return (call.arguments as? [String: Any])?[key] as!  [AnyHashable : Any]
          }
    
}
